@@ -2,7 +2,8 @@ use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
 use cosmwasm_std::{
-    to_binary, Addr, CosmosMsg, Querier, QuerierWrapper, StdResult, Uint128, WasmMsg, WasmQuery,
+    to_binary, Addr, CosmosMsg, Empty, Querier, QuerierWrapper, StdResult, Uint128, WasmMsg,
+    WasmQuery,
 };
 
 use crate::{
@@ -27,7 +28,7 @@ impl Cw20Contract {
         Ok(WasmMsg::Execute {
             contract_addr: self.addr().into(),
             msg,
-            send: vec![],
+            funds: vec![],
         }
         .into())
     }
@@ -46,7 +47,7 @@ impl Cw20Contract {
             msg: to_binary(&msg)?,
         }
         .into();
-        let res: BalanceResponse = QuerierWrapper::new(querier).query(&query)?;
+        let res: BalanceResponse = QuerierWrapper::<Empty>::new(querier).query(&query)?;
         Ok(res.balance)
     }
 
@@ -59,7 +60,7 @@ impl Cw20Contract {
             msg: to_binary(&msg)?,
         }
         .into();
-        QuerierWrapper::new(querier).query(&query)
+        QuerierWrapper::<Empty>::new(querier).query(&query)
     }
 
     /// Get allowance of spender to use owner's account
@@ -78,7 +79,7 @@ impl Cw20Contract {
             msg: to_binary(&msg)?,
         }
         .into();
-        QuerierWrapper::new(querier).query(&query)
+        QuerierWrapper::<Empty>::new(querier).query(&query)
     }
 
     /// Find info on who can mint, and how much
@@ -89,7 +90,7 @@ impl Cw20Contract {
             msg: to_binary(&msg)?,
         }
         .into();
-        QuerierWrapper::new(querier).query(&query)
+        QuerierWrapper::<Empty>::new(querier).query(&query)
     }
 
     /// returns true if the contract supports the allowance extension
